pub trait FormatValue: Display + Debug { }Expand description
Marker trait for values that can be formatted at runtime.
Blanket-implemented for all T: Display + Debug (including unsized types
such as str), which covers the vast majority of Rust types (i32, f64,
String, &str, bool, char, custom types with #[derive(Debug)] and a
Display impl, etc.).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".